---
name: Enhancement Request
about: Planned improvement or addition to functionality; non-urgent.
title: "[Enhancement]: "
labels:
  - enhancement
---

**Description of Feature or Improvement:**


**Proposed Solution:**

**Ticket Nr**
<!--Will be provided by owner -->

**New Release Checks:**
Only once all the checks below are completed should there be a new release:
- [ ] Pre-Commit successful
- [ ] CI successful
- [ ] CodeCov above 99% or justifiably less
- [ ] Badges are correct on PyPI
- [ ] Deleted the branch
- [ ] Changed current branch to `master`
